@@ -18,8 +18,11 @@
 #' @param Fns_vec Character vector of aggregation function to apply to the selected variables.
 #' Available functions are mean, median, min, max, sum, qPP (PP-th percentile), sd, var,
 #' vc (variability coefficient), skew (skewness) and kurt (kurtosis).
-#' @param by_sensor Logic value (0 or 1). If 'by_sensor=1', the function returns the observed concentrations
-#' by sensor code, while if 'by_sensor=0' (default) it returns the observed concentrations by station.
+#' @param by_sensor Logic value (T or F). If 'by_sensor=T', the function returns the observed concentrations
+#' by sensor code, while if 'by_sensor=F' (default) it returns the observed concentrations by station.
+#' @param parallel Logic value (T or F). If 'parallel=T' (default), data downloading is performed using parallel computing
+#' (socketing), while if 'parallel=F' (default) the download is performed serially. 'parallel=T' works only when
+#' 'Year' is a vector with multiple values, i.e. for a single year the serial computing is performed.
 #' @param verbose Logic value (T or F). Toggle warnings and messages. If 'verbose=T' (default) the function
 #' prints on the screen some messages describing the progress of the tasks. If 'verbose=F' any message about
 #' the progression is suppressed.
@@ -37,41 +40,50 @@
 #'    Var_vec=c("NOx","NO2"),Fns_vec=c("q25","max"),by_sensor = 0)
 #' ## Download hourly air quality data for 2020 at station 501.
 #' ## Data are reported by sensor.
-#' get_ARPA_Lombardia_AQ_data(ID_station=501,Year=2020,by_sensor = 1)
+#' get_ARPA_Lombardia_AQ_data(ID_station=501,Year=2020,by_sensor = TRUE)
 #' }
 #'
 #' @export
 
 get_ARPA_Lombardia_AQ_data <-
-  function(ID_station = NULL, Year = 2020, Frequency = "hourly", Var_vec = NULL, Fns_vec = NULL, by_sensor = 0, verbose = T) {
+  function(ID_station = NULL, Year = 2020, Frequency = "hourly", Var_vec = NULL, Fns_vec = NULL, by_sensor = F, parallel = T,verbose = T) {
 
+    ##### Downloading data
     if (length(Year) == 1) {
       Aria <- get_ARPA_Lombardia_AQ_data_1y(ID_station = ID_station, Year = Year, Var_vec = Var_vec,
                                             by_sensor = by_sensor, verbose = verbose)
-      attr(Aria, "class") <- c("ARPALdf","ARPALdf_AQ","tbl_df","tbl","data.frame")
     } else {
-      cl <- parallel::makeCluster(parallel::detectCores()/2, type = 'PSOCK')
-      doParallel::registerDoParallel(cl)
-      parallel::clusterExport(cl, varlist = c("get_ARPA_Lombardia_AQ_data_1y",
-                                              "Time_aggregate",
-                                              "AQ_metadata_reshape",
-                                              "url_dataset_year",
-                                              "%>%"),
-                              envir=environment())
-      if (verbose==T) {
-        cat("Parallel (",parallel::detectCores()/2,"cores) download, import and process of ARPA Lombardia data: started at", as.character(Sys.time()), "\n")
+      if (parallel == T) {
+        cl <- parallel::makeCluster(min(length(Year),parallel::detectCores()/2), type = 'PSOCK')
+        doParallel::registerDoParallel(cl)
+        parallel::clusterExport(cl, varlist = c("get_ARPA_Lombardia_AQ_data_1y",
+                                                "Time_aggregate",
+                                                "AQ_metadata_reshape",
+                                                "url_dataset_year",
+                                                "%>%"),
+                                envir=environment())
+        if (verbose==T) {
+          cat("Parallel (",min(length(Year),parallel::detectCores()/2),"cores) download, import and process of ARPA Lombardia data: started at", as.character(Sys.time()), "\n")
+        }
+        Aria <- dplyr::bind_rows(parallel::parLapply(cl = cl,
+                                                     X = Year,
+                                                     fun = get_ARPA_Lombardia_AQ_data_1y,
+                                                     ID_station = ID_station,
+                                                     Var_vec = Var_vec))
+        if (verbose==T) {
+          cat("Parallel download, import and process of ARPA Lombardia data: ended at", as.character(Sys.time()), "\n")
+        }
+        parallel::stopCluster(cl)
+      } else {
+        Aria_d <- vector("list", length = length(Year))
+        for (j in 1:length(Year)) {
+          Aria_d[[j]] <- get_ARPA_Lombardia_AQ_data_1y(ID_station = ID_station, Year = Year[j], Var_vec = Var_vec,
+                                                       by_sensor = by_sensor, verbose = verbose)
+        }
+        Aria <- dplyr::bind_rows(Aria_d)
       }
-      Aria <- dplyr::bind_rows(parallel::parLapply(cl = cl,
-                                                   X = Year,
-                                                   fun = get_ARPA_Lombardia_AQ_data_1y,
-                                                   ID_station = ID_station,
-                                                   Var_vec = Var_vec))
-      if (verbose==T) {
-        cat("Parallel download, import and process of ARPA Lombardia data: ended at", as.character(Sys.time()), "\n")
-      }
-      parallel::stopCluster(cl)
-      attr(Aria, "class") <- c("ARPALdf","ARPALdf_AQ","tbl_df","tbl","data.frame")
     }
+    attr(Aria, "class") <- c("ARPALdf","ARPALdf_AQ","tbl_df","tbl","data.frame")
 
     if (is.null(Var_vec) & is.null(Fns_vec)) {
       vv <- c("Ammonia","Arsenic","Benzene","Benzo_a_pyrene","BlackCarbon","Cadmium",
@@ -120,18 +132,29 @@ get_ARPA_Lombardia_AQ_data <-
                                     Frequency == "weekly" ~ "weeks",
                                     Frequency == "monthly" ~ "months",
                                     Frequency == "yearly" ~ "years")
+
       Aria <- Aria %>%
-        dplyr::arrange(.data$Date) %>% ### new
-        dplyr::filter(lubridate::year(.data$Date) %in% Year)
-      dt <- seq(min(Aria$Date),max(Aria$Date), by = freq_unit)
-      st <- unique(Aria$IDStation)
-      grid <- data.frame(tidyr::expand_grid(dt,st))
-      st_n <- Aria %>%
-        dplyr::distinct(.data$IDStation,.data$NameStation) %>%
-        dplyr::filter(!is.na(.data$IDStation),!is.na(.data$NameStation))
-      colnames(grid) <- c("Date","IDStation")
-      grid <- dplyr::left_join(grid,st_n,by="IDStation")
-      Aria <- dplyr::left_join(grid,Aria, by=c("Date","IDStation","NameStation"))
+        dplyr::arrange(.data$Date) %>%
+        dplyr::filter(lubridate::year(.data$Date) %in% Year) %>%
+        tidyr::pivot_longer(cols = -c(.data$Date,.data$IDStation,.data$NameStation),
+                            names_to = "Measure", values_to = "Value") %>%
+        tidyr::pivot_wider(names_from = .data$Date, values_from = .data$Value) %>%
+        tidyr::pivot_longer(cols = -c(.data$Measure,.data$IDStation,.data$NameStation),
+                            names_to = "Date", values_to = "Value") %>%
+        tidyr::pivot_wider(names_from = .data$Measure, values_from = .data$Value)
+
+      # Aria <- Aria %>%
+      #   dplyr::arrange(.data$Date) %>% ### new
+      #   dplyr::filter(lubridate::year(.data$Date) %in% Year)
+      # dt <- seq(min(Aria$Date),max(Aria$Date), by = freq_unit)
+      # st <- unique(Aria$IDStation)
+      # grid <- data.frame(tidyr::expand_grid(dt,st))
+      # st_n <- Aria %>%
+      #   dplyr::distinct(.data$IDStation,.data$NameStation) %>%
+      #   dplyr::filter(!is.na(.data$IDStation),!is.na(.data$NameStation))
+      # colnames(grid) <- c("Date","IDStation")
+      # grid <- dplyr::left_join(grid,st_n,by="IDStation")
+      # Aria <- dplyr::left_join(grid,Aria, by=c("Date","IDStation","NameStation"))
 
       if (verbose==T) {
         cat("Processing ARPA Lombardia data: ended at", as.character(Sys.time()), "\n")
